@@ -5,7 +5,7 @@ from flask_smorest import abort
 from bemserver_core.model import EventByBuilding
 from bemserver_core.exceptions import BEMServerCoreCampaignError
 
-from bemserver_api import Blueprint
+from bemserver_api import Blueprint, SQLCursorPage
 from bemserver_api.database import db
 
 from .schemas import (
@@ -25,15 +25,14 @@ blp = Blueprint(
 @blp.route("/")
 class EventByBuildingViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.arguments(EventByBuildingQueryArgsSchema, location="query")
     @blp.response(200, EventByBuildingSchema(many=True))
+    @blp.paginate(SQLCursorPage)
     def get(self, args):
         """List event x building associations"""
         return EventByBuilding.get(**args)
 
     @blp.login_required
-    @blp.etag
     @blp.arguments(EventByBuildingSchema)
     @blp.response(201, EventByBuildingSchema)
     @blp.catch_integrity_error
@@ -50,7 +49,6 @@ class EventByBuildingViews(MethodView):
 @blp.route("/<int:item_id>")
 class EventByBuildingByIdViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.response(200, EventByBuildingSchema)
     def get(self, item_id):
         """Get event x building association by ID"""
