@@ -5,7 +5,7 @@ from flask_smorest import abort
 from bemserver_core.model import EventBySpace
 from bemserver_core.exceptions import BEMServerCoreCampaignError
 
-from bemserver_api import Blueprint
+from bemserver_api import Blueprint, SQLCursorPage
 from bemserver_api.database import db
 
 from .schemas import (
@@ -25,15 +25,14 @@ blp = Blueprint(
 @blp.route("/")
 class EventBySpaceViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.arguments(EventBySpaceQueryArgsSchema, location="query")
     @blp.response(200, EventBySpaceSchema(many=True))
+    @blp.paginate(SQLCursorPage)
     def get(self, args):
         """List event x space associations"""
         return EventBySpace.get(**args)
 
     @blp.login_required
-    @blp.etag
     @blp.arguments(EventBySpaceSchema)
     @blp.response(201, EventBySpaceSchema)
     @blp.catch_integrity_error
@@ -50,7 +49,6 @@ class EventBySpaceViews(MethodView):
 @blp.route("/<int:item_id>")
 class EventBySpaceByIdViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.response(200, EventBySpaceSchema)
     def get(self, item_id):
         """Get event x space association by ID"""
