@@ -6,6 +6,8 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import TimeseriesByEvent
 
 from bemserver_api import AutoSchema, Schema
+from ..timeseries.schemas import TimeseriesSchema
+from ..events.schemas import EventSchema
 
 
 class TimeseriesByEventSchema(AutoSchema):
@@ -13,6 +15,8 @@ class TimeseriesByEventSchema(AutoSchema):
         model = TimeseriesByEvent
 
     id = msa.auto_field(dump_only=True)
+    timeseries = ma.fields.Nested(TimeseriesSchema(exclude=("id",)), dump_only=True)
+    event = ma.fields.Nested(EventSchema(exclude=("id",)), dump_only=True)
 
 
 class TimeseriesByEventQueryArgsSchema(Schema):
