@@ -4,7 +4,7 @@ from flask_smorest import abort
 
 from bemserver_core.model import TimeseriesBySite
 
-from bemserver_api import Blueprint
+from bemserver_api import Blueprint, SQLCursorPage
 from bemserver_api.database import db
 
 from .schemas import (
@@ -24,15 +24,14 @@ blp = Blueprint(
 @blp.route("/")
 class TimeseriesBySiteViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.arguments(TimeseriesBySiteQueryArgsSchema, location="query")
     @blp.response(200, TimeseriesBySiteSchema(many=True))
+    @blp.paginate(SQLCursorPage)
     def get(self, args):
         """List timeseries x site associations"""
         return TimeseriesBySite.get(**args)
 
     @blp.login_required
-    @blp.etag
     @blp.arguments(TimeseriesBySiteSchema)
     @blp.response(201, TimeseriesBySiteSchema)
     @blp.catch_integrity_error
@@ -46,7 +45,6 @@ class TimeseriesBySiteViews(MethodView):
 @blp.route("/<int:item_id>")
 class TimeseriesBySiteByIdViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.response(200, TimeseriesBySiteSchema)
     def get(self, item_id):
         """Get timeseries x site association by ID"""
@@ -56,28 +54,11 @@ class TimeseriesBySiteByIdViews(MethodView):
         return item
 
     @blp.login_required
-    @blp.etag
-    @blp.arguments(TimeseriesBySiteSchema)
-    @blp.response(200, TimeseriesBySiteSchema)
-    @blp.catch_integrity_error
-    def put(self, new_item, item_id):
-        """Update an existing timeseries x site association"""
-        item = TimeseriesBySite.get_by_id(item_id)
-        if item is None:
-            abort(404)
-        blp.check_etag(item, TimeseriesBySiteSchema)
-        item.update(**new_item)
-        db.session.commit()
-        return item
-
-    @blp.login_required
-    @blp.etag
     @blp.response(204)
     def delete(self, item_id):
         """Delete a timeseries x site association"""
         item = TimeseriesBySite.get_by_id(item_id)
         if item is None:
             abort(404)
-        blp.check_etag(item, TimeseriesBySiteSchema)
         item.delete()
         db.session.commit()
